==> cert_creation-1.7.8-sources.jar: ocr/activity/IDReadyActivity.java <==
package ocr.activity;

import android.Manifest;
import android.content.pm.PackageManager;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.v4.content.ContextCompat;
import android.text.TextUtils;
import android.view.View;
import android.widget.Button;

import com.alibaba.android.arouter.facade.annotation.Autowired;
import com.alibaba.android.arouter.facade.annotation.Route;
import com.alibaba.android.arouter.launcher.ARouter;
import com.squareup.otto.Subscribe;
import com.xdja.aspectjmodule.annotation.XdjaPermission;
import com.xdja.cryptodev.CryptoDevType;
import com.xdja.safeclient.certcreation.R;
import com.xdja.safeclient.certcreation.activity.ActivityPath;
import com.xdja.safeclient.certcreation.activity.BaseActivity;
import com.xdja.safeclient.certcreation.device.DeviceWrapper;
import com.xdja.safeclient.certcreation.event.FinishActivity;
import com.xdja.safeclient.certcreation.util.CryptoDevTypeUtil;
import com.xdja.safeclient.certcreation.util.ModuleToast;
import com.xdja.safeclient.certcreation.util.SharePreferencesUtil;

/**
 * 证件拍照引导页
 * 标题-上传身份证照片
 *
 */

@Route(name = ActivityPath.NAME_ID_READY, path = ActivityPath.ACTIVITY_CAMERA_ID_READY)
public class IDReadyActivity extends BaseActivity {

    @Autowired()
    public int type;
    String        cardNo;
    CryptoDevType cardType;
    String        phone;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_camera_id_ready);
        left_title_tv.invalidate();
        hideBG();

        cardType = CryptoDevTypeUtil.formatType(SharePreferencesUtil.getCurrentDevType(this));
        cardNo = DeviceWrapper.getInstance().getCardID(cardType);

        phone = SharePreferencesUtil.getPhoneNum(this);

        if (TextUtils.isEmpty(cardNo)) {
            ModuleToast.show(context, R.string.cert_creation_card_device_error);
            return;
        }

        Button bt_startdect = (Button) findViewById(R.id.start);

        bt_startdect.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                next();
            }
        });


    }

    @Override
    public boolean valid() {
        return ContextCompat.checkSelfPermission(IDReadyActivity.this, Manifest.permission.CAMERA) == PackageManager.PERMISSION_GRANTED;
    }

    @Override
    public String nextActivity() {
        return ActivityPath.ACTIVITY_SELFIE;
    }

    @Override
    public void route() {
        super.route();
        ARouter.getInstance()
                .build(nextActivity())
                .withInt("type", type)
                .withString("cardNo", cardNo)
                .withSerializable("cardType", cardType)
                .withString("phone", phone)
                .navigation(this);
    }

    @XdjaPermission(permissions = {
            Manifest.permission.CAMERA,
    })
    private void requestCamera() {

    }


    @Override
    public void onRequestPermissionsResult(int requestCode, @NonNull String[] permissions, @NonNull int[] grantResults) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults);

        if (permissions[0].equals(Manifest.permission.CAMERA) && grantResults[0] == PackageManager.PERMISSION_GRANTED) {
            next();
        }

    }

    @Override
    protected int getTitleRes() {
        return R.string.cert_creation_selfie_photo_title;
    }

    @Subscribe

    public void handleFinishActivity(FinishActivity activity) {
        finish();
    }

}

==> cert_creation-1.8.1_3-sources.jar: ocr/activity/IDReadyActivity.java <==
package ocr.activity;

import android.Manifest;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.v4.content.ContextCompat;
import android.text.TextUtils;
import android.view.View;
import android.widget.Button;

import com.alibaba.android.arouter.facade.annotation.Autowired;
import com.alibaba.android.arouter.facade.annotation.Route;
import com.alibaba.android.arouter.launcher.ARouter;
import com.squareup.otto.Subscribe;
import com.xdja.aspectjmodule.annotation.XdjaPermission;
import com.xdja.cryptodev.CryptoDevType;
import com.xdja.safeclient.certcreation.BuildConfig;
import com.xdja.safeclient.certcreation.R;
import com.xdja.safeclient.certcreation.activity.ActivityPath;
import com.xdja.safeclient.certcreation.activity.BaseActivity;
import com.xdja.safeclient.certcreation.activity.SelfieActivity;
import com.xdja.safeclient.certcreation.device.DeviceWrapper;
import com.xdja.safeclient.certcreation.event.FinishActivity;
import com.xdja.safeclient.certcreation.util.CryptoDevTypeUtil;
import com.xdja.safeclient.certcreation.util.ModuleToast;
import com.xdja.safeclient.certcreation.util.SharePreferencesUtil;

import static com.xdja.safeclient.certcreation.activity.ActivityParam.PHOTO_TYPE;

/**
 * 证件拍照引导页
 * 标题-上传身份证照片
 */

@Route(name = ActivityPath.NAME_ID_READY, path = ActivityPath.ACTIVITY_CAMERA_ID_READY)
public class IDReadyActivity extends BaseActivity {

    @Autowired()
    public int type;

    String cardNo;
    CryptoDevType cardType;
    String phone;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_camera_id_ready);
        left_title_tv.invalidate();
        hideBG();

        cardType = CryptoDevTypeUtil.formatType(SharePreferencesUtil.getCurrentDevType(this));
        cardNo = DeviceWrapper.getInstance().getCardID(cardType);

        phone = SharePreferencesUtil.getPhoneNum(this);

        if (TextUtils.isEmpty(cardNo)) {
            ModuleToast.show(context, R.string.cert_creation_card_device_error);
            return;
        }

        Button bt_startdect = (Button) findViewById(R.id.start);

        bt_startdect.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                next();
            }
        });


    }

    @Override
    protected void getIntentData() {
        super.getIntentData();

        type = getIntent().getIntExtra(PHOTO_TYPE, 0);

    }

    @Override
    public boolean valid() {
        return ContextCompat.checkSelfPermission(IDReadyActivity.this, Manifest.permission.CAMERA) == PackageManager.PERMISSION_GRANTED;
    }

    @Override
    public String nextActivity() {
        return ActivityPath.ACTIVITY_SELFIE;
    }

    @Override
    public void route() {
        super.route();

        if (BuildConfig.isAAR || BaseActivity.DEBUG_AAR) {

            Intent intent = new Intent(this, SelfieActivity.class);
            intent.putExtra("type", type);
            intent.putExtra("cardNo", cardNo);
            intent.putExtra("cardType", cardType);
            intent.putExtra("phone", phone);
            startActivity(intent);

        } else {

            ARouter.getInstance()
                    .build(nextActivity())
                    .withInt("type", type)
                    .withString("cardNo", cardNo)
                    .withSerializable("cardType", cardType)
                    .withString("phone", phone)
                    .navigation(this);
        }

    }

    @XdjaPermission(permissions = {
            Manifest.permission.CAMERA,
    })
    private void requestCamera() {

    }


    @Override
    public void onRequestPermissionsResult(int requestCode, @NonNull String[] permissions, @NonNull int[] grantResults) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults);

        if (permissions[0].equals(Manifest.permission.CAMERA) && grantResults[0] == PackageManager.PERMISSION_GRANTED) {
            next();
        }

    }

    @Override
    protected int getTitleRes() {
        return R.string.cert_creation_selfie_photo_title;
    }

    @Subscribe

    public void handleFinishActivity(FinishActivity activity) {
        finish();
    }

}
